CREATE TABLE ASSET_RENTAL_STATUS (
  ID_ASSET_RENTAL_STATUS NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(200 CHAR),
  INTERNAL_DESCRIPTION VARCHAR2(200 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT ASSET_RENTAL_STATUS_PK PRIMARY KEY (ID_ASSET_RENTAL_STATUS)
);

INSERT INTO ASSET_RENTAL_STATUS(ID_ASSET_RENTAL_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) VALUES
(1, 'Rented', 'Rented', 'Y');

INSERT INTO ASSET_RENTAL_STATUS(ID_ASSET_RENTAL_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) VALUES
(2, 'Returned', 'Returned', 'Y');

INSERT INTO ASSET_RENTAL_STATUS(ID_ASSET_RENTAL_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) VALUES
(-10, 'Deleted', 'Deleted', 'N');

CREATE TABLE ASSET_RENTAL (
  ID_ASSET_RENTAL NUMBER NOT NULL,
  ID_PLOVILA NUMBER,
  ID_LASTNIKA NUMBER,
  ID_ASSET NUMBER,
  STATUS NUMBER,
  DATE_FROM DATE,
  DATE_TO DATE,
  "COMMENT" VARCHAR2(500 CHAR),
  CONSTRAINT ASSET_RENTAL_PK PRIMARY KEY (ID_ASSET_RENTAL)
);

ALTER TABLE ASSET_RENTAL
ADD CONSTRAINT ASSET_RENTAL_ID_PLOVILA_FK FOREIGN KEY (ID_PLOVILA) REFERENCES PLOVILA(ID);

ALTER TABLE ASSET_RENTAL
ADD CONSTRAINT ASSET_RENTAL_ID_LASTNIKA_FK FOREIGN KEY (ID_LASTNIKA) REFERENCES KUPCI(ID);

ALTER TABLE ASSET_RENTAL
ADD CONSTRAINT ASSET_RENTAL_ID_ASSET_FK FOREIGN KEY (ID_ASSET) REFERENCES ASSET(ID_ASSET);

ALTER TABLE ASSET_RENTAL
ADD CONSTRAINT ASSET_RENTAL_STATUS_FK FOREIGN KEY (STATUS) REFERENCES ASSET_RENTAL_STATUS(ID_ASSET_RENTAL_STATUS);

CREATE INDEX IX_ASSET_RENTAL_ID_PLOVILA ON ASSET_RENTAL(ID_PLOVILA);

CREATE INDEX IX_ASSET_RENTAL_ID_ASSET ON ASSET_RENTAL(ID_ASSET);

CREATE SEQUENCE ASSET_RENTAL_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE OR REPLACE VIEW V_ASSET_RENTAL AS (
SELECT AR.ID_ASSET_RENTAL, AR.ID_PLOVILA, AR.ID_LASTNIKA, AR.ID_ASSET, AR.STATUS, AR.DATE_FROM, AR.DATE_TO, AR."COMMENT", 
P.IME AS BOAT_NAME,  A.NAME AS ASSET_NAME, S.DESCRIPTION AS STATUS_DESCRIPTION,
(CASE WHEN (SELECT VREDNOST FROM S_NASTAVITVE WHERE FILTER = 'MARINA' AND SEKCIJA = 'MARINA' AND NAZIV = 'ChangeFirstLastName') = '1' THEN (K.IME || ' ' || K.PRIIMEK) ELSE (K.PRIIMEK || ' ' || K.IME) END) AS OWNER
FROM ASSET_RENTAL AR
LEFT OUTER JOIN PLOVILA P ON P.ID = AR.ID_PLOVILA
LEFT OUTER JOIN KUPCI K ON K.ID = AR.ID_LASTNIKA
LEFT OUTER JOIN ASSET A ON A.ID_ASSET = AR.ID_ASSET
LEFT OUTER JOIN ASSET_RENTAL_STATUS S ON S.ID_ASSET_RENTAL_STATUS = AR.STATUS
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (2272, SYSDATE, '5.5', 2192, 'Asset rental')
;
